@@ -469,10 +469,6 @@ define(function(require) {
           .on('mousedown.cstatx', function() {
             if (d3.event.shiftKey) {
               xStart = d3.event.x;
-              el.select('.xaxis')
-                .on('mousedown.zoom', null)
-                .on('mousemove.zoom', null)
-                .on('mouseup.zoom', null);
               curXScale = zoom.scale();
               d3.select('body')
                 .on('mousemove.cstatx', function() {
